///////////////////////////////////////////////////////////////////////////////
//
// File:    global.h
// Author:  Roger Rowland
//
// Created: November 2014
//
///////////////////////////////////////////////////////////////////////////////

#ifndef GLOBAL_H
#define	GLOBAL_H

// global includes
#include <stdint.h>

///////////////////////////////////////////////////////////////////////////////
// definitions for delay macros
///////////////////////////////////////////////////////////////////////////////

#define _XTAL_FREQ  20000000L                   // oscillator frequency 20MHz

///////////////////////////////////////////////////////////////////////////////
// LCD and 74HC595 connections (note that LCD-E must also be physically
// connected to the storage register clock input, SHR_RCK, which is pin 12)
///////////////////////////////////////////////////////////////////////////////

#define LCD_E           RA0                     // HD44780 LCD Enable
#define LCD_E_TRIS      TRISAbits.TRISA0        // HD44780 LCD Enable TRIS
#define SHR_SI          RA1                     // 74HC595 Serial In
#define SHR_SI_TRIS     TRISAbits.TRISA1        // 74HC595 Serial In TRIS
#define SHR_SCK         RB5                     // 74HC595 Shift Clock
#define SHR_SCK_TRIS    TRISBbits.TRISB5        // 74HC595 Shift Clock TRIS

///////////////////////////////////////////////////////////////////////////////
// LED matrix connections to cascaded MAX7219's
///////////////////////////////////////////////////////////////////////////////

#define LED_DIN         RA2                     // MAX7219 Data Input
#define LED_DIN_TRIS    TRISAbits.TRISA2        // MAX7219 Data Input TRIS
#define LED_CS          RA3                     // MAX7219 Chip Select / Load
#define LED_CS_TRIS     TRISAbits.TRISA3        // MAX7219 Chip Select / Load TRIS
#define LED_CLK         RA4                     // MAX7219 Clock
#define LED_CLK_TRIS    TRISAbits.TRISA4        // MAX7219 Clock TRIS

///////////////////////////////////////////////////////////////////////////////
// PS/2 mouse connections (nb - these are open collector)
///////////////////////////////////////////////////////////////////////////////

#define PS2_PORT        PORTB                   // PS/2 mouse port
#define PS2_CLK_BIT     b0                      // PS/2 mouse clock bit
#define PS2_DAT_BIT     b1                      // PS/2 mouse data bit
#define PS2_CLK         RB0                     // PS/2 mouse clock
#define PS2_CLK_TRIS    TRISBbits.TRISB0        // PS/2 mouse clock TRIS
#define PS2_DAT         RB1                     // PS/2 mouse data
#define PS2_DAT_TRIS    TRISBbits.TRISB1        // PS/2 mouse data TRIS

///////////////////////////////////////////////////////////////////////////////
// useful typedefs
///////////////////////////////////////////////////////////////////////////////

typedef union                                   // 8-bit byte as eight bits or two nibbles
{
    uint8_t uByte;
    struct
    {
        unsigned b0:1, b1:1, b2:1, b3:1;        // 8 individual bits, lsb first
        unsigned b4:1, b5:1, b6:1, b7:1;
    };
    struct
    {
        unsigned uLSN : 4;                      // least significant nibble
        unsigned uMSN : 4;                      // most significant nibble
    };
} t_byte;

typedef union                                   // 16-bit short as two 8-bit bytes
{
    uint16_t uShort;                            // unsigned short
    int16_t nShort;                             // signed short
    struct
    {
        uint8_t uLSB;                           // least significant byte
        uint8_t uMSB;                           // most significant byte
    };
} t_short;

#endif	/* GLOBAL_H */

